# Summary

* [Introduction](README.md)
  * [Introduction to OAuth 2.0 and OpenID Connect](README.md#introduction-to-oauth-20-and-openid-connect)
  * [Introduction to Hydra](README.md#introduction-to-hydra)
  * [OAuth2 Case Study](README.md#oauth-20-case-study)
* [Introduction Tutorial (5 minutes)](tutorial.md)
* [Dependencies](environment.md)
* Understanding Hydra
  * [OAuth2 & OpenID Connect](oauth2.md)
    * [Overview](oauth2.md#overview)
    * [Confirming User Consent: Consent Flow](oauth2.md#consent-flow)
    * [Validating Tokens: OAuth2 Token Introspection](oauth2.md#oauth2-token-introspection)
    * [OAuth2 Scopes](oauth2.md#oauth2-scopes)
  * [JSON Web Keys](jwk.md)
  * [Access Control](access-control.md)
    - [Introduction](access-control.md#introduction)
    - [Warden API](access-control.md#warden-api)
    - [Groups](access-control.md#groups)
    - [Best Practices](access-control.md#best-practices)
      - [Scalability](access-control.md#scalability)
      - [URNs](access-control.md#urns)
      - [Scope the Organization Name](access-control.md#scope-the-organization-name)
      - [Scope Actions, Resources and Subjects](access-control.md#scope-actions-resources-and-subjects)
      - [Multi-Tenant Systems](access-control.md#multi-tenant-systems)
    - [Conditions & Context](access-control.md#conditions-&-context)
      - [CIDR Condition](access-control.md#cidr-condition)
      - [String Equal Condition](access-control.md#string-equal-condition)
      - [String Match Condition](access-control.md#string-match-condition)
      - [Subject Condition](access-control.md#subject-condition)
      - [String Pairs Equal Condition](access-control.md#string-pairs-equal-condition)
- [Install, Configure and Run ORY Hydra (15 minutes)](install.md#install-configure-and-run-ory-hydra)
  - [Create a Network](install.md#create-a-network)
  - [Start a PostgreSQL container](install.md#start-a-postgresql-container)
  - [Install and run ORY Hydra](install.md#install-and-run-ory-hydra)
    - [Install ORY Hydra without Docker](install.md#install-ory-hydra-without-docker)
      - [Download binaries](install.md#download-binaries)
      - [Build from source](install.md#build-from-source)
  - [Configure ORY Hydra](install.md#configure-ory-hydra)
    - [Setting up the consent app](install.md#setting-up-the-consent-app)
  - [Perform OAuth 2.0 Flow](install.md#perform-oauth-20-flow)
- [Security Overview](security.md#security-overview)
  - [OAuth 2.0 Security Overview](security.md#oauth-20-security-overview)
    - [Advanced Token Validation (Datastore Security)](security.md#advanced-token-validation-datastore-security)
    - [Access Control Policies](security.md#access-control-policies)
  - [Cryptography](security.md#cryptography)
    - [AES-GCM](security.md#aes-gcm)
    - [RS256](security.md#rs256)
    - [HMAC-SHA256](security.md#hmac-sha256)
    - [BCrypt](security.md#bcrypt)
  - [Access Control](security.md#how-does-access-control-work-with-hydra)
* [Telemetry](telemetry.md)
* How-To
  * [Running Hydra in production](how-to/production.md)
* [SDKs](sdk.md)
  * [SDK for Go](sdk/go.md)
  * [SDK for JavaScript](sdk/js.md)
  * [Other languages](sdk.md)
* [Contribute](contribute.md)
* [FAQ](faq.md)
  - [How can I control SQL connection limits?](faq.md#how-can-i-control-sql-connection-limits)
  - [Why is the Resource Owner Password Credentials grant not supported?](faq.md#why-is-the-resource-owner-password-credentials-grant-not-supported)
  - [Should I use OAuth2 tokens for authentication?](faq.md#should-i-use-oauth2-tokens-for-authentication)
  - [How to deal with mobile apps?](faq.md#how-to-deal-with-mobile-apps)
  - [How should I run migrations?](faq.md#how-should-i-run-migrations)
  - [What does the installation process look like?](faq.md#what-does-the-installation-process-look-like)
  - [What does a migration process look like?](faq.md#what-does-a-migration-process-look-like)
  - [How can I do this in docker?](faq.md#how-can-i-do-this-in-docker)
  - [Can I set the log level to warn, error, debug, ...?](faq.md#can-i-set-the-log-level-to-warn-error-debug-)
  - [How can I import TLS certificates?](faq.md#how-can-i-import-tls-certificates)
  - [Is there an HTTP API Documentation?](faq.md#is-there-an-http-api-documentation)
  - [How can I disable HTTPS for testing?](faq.md#how-can-i-disable-https-for-testing)
  - [MySQL gives `unsupported Scan, storing driver.Value type []uint8 into type *time.Time`](faq.md#mysql-gives-unsupported-scan-storing-drivervalue-type-uint8-into-type-timetime)
  - [Insufficient Entropy](faq.md#insufficient-entropy)
  - [The docker image exits immediately](faq.md#the-docker-image-exits-immediately)
  - [I get compile errors!](faq.md#i-get-compile-errors)
  - [Is JWT supported?](faq.md#is-jwt-supported)
  - [Refreshing tokens](faq.md#refreshing-tokens)
  - [Revoking tokens & log out](faq.md#revoking-tokens-&-log-out)
  - [Operational Considerations](faq.md#operational-considerations)
    - [Managing Client/Policy Definitions](faq.md#managing-clientpolicy-definitions)
  - [Recovering root client access](faq.md#recovering-root-client-access)
